Test for jQuery validate() plugin

# jQuery Validation Plugin Demo

Login Form

Username

Password

#### There are serious errors in your form submission, please see below for details.

1. Please enter your email address
2. Please enter your phone number (between 2 and 8 characters)
3. Please enter your address (at least 3 characters)
4. Please select an image (png, jpg, jpeg, gif)
5. Please select a document (doc, docx, txt, pdf)

Validating a complete form

Email

Favorite Color

Phone

Address

Avatar

Please agree to our policy

CV

#### There are serious errors in your form submission, please see details above the form!

Back to main page